@@ -286,7 +286,7 @@ def get_filtered_amount_of_data(
 	current: models.HourlyStats = models.HourlyStats.get_or_none(
 		participant=notnull(participant),
 		data_source=notnull(data_source),
-		ts=till_ts.replace(minute=0, second=0, microsecond=0) + td(hours=1)
+		ts=till_ts.replace(minute=0, second=0, microsecond=0)
 	)
 	if not current:
 		current: models.HourlyStats = models.HourlyStats.filter(
